==> hledger-web-1.14.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.14.1
id: hledger-web-1.14.1-7JWmKpvYh68E1rxIJDfEBY
key: hledger-web-1.14.1-7JWmKpvYh68E1rxIJDfEBY
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 4eeb9ca3facee9dbb861c0ab64d6112c
exposed: True
exposed-modules:
    Hledger.Web Hledger.Web.Application Hledger.Web.Foundation
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Json Hledger.Web.Main
    Hledger.Web.Settings Hledger.Web.Settings.StaticFiles
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.14.1-7JWmKpvYh68E1rxIJDfEBY
depends:
    Decimal-0.5.1-HbE7jjGKIya5lM4gHWrRW6
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    clientsession-0.9.1.2-38NHrIsylOx2AXJejwSg9m
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-1rtgJXlCmiO4uvSrqLTkUm
    conduit-extra-1.3.1.1-8uskN5QWhT7JNnQnEclXyj containers-0.6.0.1
    data-default-0.7.1.1-3C0tdSCD1lzIk8WkrvBOoZ directory-1.3.3.0
    filepath-1.4.2.1 hjsmin-0.2.0.2-EavLvoT0jfd25LMHcIIpPL
    hledger-1.14.2-3HaXaOquBw25d5BI3Sy2Ww
    hledger-lib-1.14.1-Ist7qQN3gJrJFEYZZ9dwqC
    http-client-0.6.2-FYzm0eoFnV2JqsXDvGiJPm
    http-conduit-2.3.6.1-DjTFH2JH1kS7mVFY31lqys
    http-types-0.12.3-IdIFkPvozmRFdXetXaEgxE
    json-0.9.3-GMBm0GlRjL45CY2W2ruX29
    megaparsec-7.0.4-1MZB8g6cytp9p69U9RRMNX mtl-2.2.2
    shakespeare-2.0.20-6xrWTIBWo4G9CLwye8ZEHQ template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    wai-3.2.2-6o6QSnPVpAu2Kn1dd7YFx6
    wai-extra-3.0.25-Hj7kEcnovaL1AnTZ3kIwJF
    wai-handler-launch-3.0.2.4-1v2KAkZGt0ZGAYGPyPoRIm
    warp-3.2.26-AEy9x1phFQLJUH2ZcSjXLl
    yaml-0.11.0.0-A3ZVfV7i42VBoOdDF6ARDI
    yesod-1.6.0-32TRs7955fwDnq2kjNBC1t
    yesod-core-1.6.13-FuIXkMwn6Zx1kQfGPYCzsh
    yesod-form-1.6.4-AyY14wjaartBPIvryrsPxS
    yesod-static-1.6.0.1-LZz17dJJkXTLv0fofwUXYN
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.14.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.14.1
id: hledger-web-1.14.1-CuB95u6uN5444zQZX5LWRb
key: hledger-web-1.14.1-CuB95u6uN5444zQZX5LWRb
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 8dd6b303059f8ef6ce4909a63e5b92bd
exposed: True
exposed-modules:
    Hledger.Web Hledger.Web.Application Hledger.Web.Foundation
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Json Hledger.Web.Main
    Hledger.Web.Settings Hledger.Web.Settings.StaticFiles
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common
hidden-modules: Paths_hledger_web
import-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-web-1.14.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.14.1-CuB95u6uN5444zQZX5LWRb
depends:
    Decimal-0.5.1-HbE7jjGKIya5lM4gHWrRW6
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    clientsession-0.9.1.2-38NHrIsylOx2AXJejwSg9m
    cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    conduit-1.3.1.1-1rtgJXlCmiO4uvSrqLTkUm
    conduit-extra-1.3.1.1-8uskN5QWhT7JNnQnEclXyj containers-0.6.0.1
    data-default-0.7.1.1-3C0tdSCD1lzIk8WkrvBOoZ directory-1.3.3.0
    filepath-1.4.2.1 hjsmin-0.2.0.2-EavLvoT0jfd25LMHcIIpPL
    hledger-1.14.2-3HaXaOquBw25d5BI3Sy2Ww
    hledger-lib-1.14.1-Ist7qQN3gJrJFEYZZ9dwqC
    http-client-0.6.2-FYzm0eoFnV2JqsXDvGiJPm
    http-conduit-2.3.6.1-DjTFH2JH1kS7mVFY31lqys
    http-types-0.12.3-IdIFkPvozmRFdXetXaEgxE
    json-0.9.3-GMBm0GlRjL45CY2W2ruX29
    megaparsec-7.0.4-1MZB8g6cytp9p69U9RRMNX mtl-2.2.2
    shakespeare-2.0.20-6xrWTIBWo4G9CLwye8ZEHQ template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    wai-3.2.2-6o6QSnPVpAu2Kn1dd7YFx6
    wai-extra-3.0.25-Hj7kEcnovaL1AnTZ3kIwJF
    wai-handler-launch-3.0.2.4-1v2KAkZGt0ZGAYGPyPoRIm
    warp-3.2.26-AEy9x1phFQLJUH2ZcSjXLl
    yaml-0.11.0.0-A3ZVfV7i42VBoOdDF6ARDI
    yesod-1.6.0-6jrMvaE2rVf92r7Jq4o9V4
    yesod-core-1.6.13-FuIXkMwn6Zx1kQfGPYCzsh
    yesod-form-1.6.4-5vTPZS0Oyc47Q9H5BA3CTF
    yesod-static-1.6.0.1-2zvC50NgrccAbfA30gTbFR
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
